/**
 * OW2 Specifications
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EntityNotFoundException.java 5417 2010-03-24 09:04:14Z benoitf $
 * --------------------------------------------------------------------------
 */

package javax.persistence;

/**
 * The EntityNotFoundException is thrown by the persistence provider when an
 * entity reference obtained by getReference is accessed but the entity does not
 * exist. It is also thrown by the refresh operation when the entity no longer
 * exists in the database. The current transaction, if one is active, will be
 * marked for rollback.
 * @see <a href="http://jcp.org/en/jsr/detail?id=317">JPA 2.0 specification</a>
 * @author Florent Benoit
 * @since JPA 1.0 version.
 */
public class EntityNotFoundException extends PersistenceException {

    /**
     * UID for serialization.
     */
    private static final long serialVersionUID = 6158102413991583659L;

    /**
     * Default constructor : builds an exception with an empty message.
     */
    public EntityNotFoundException() {
        super();
    }

    /**
     * Build an exception with the given message.
     * @param message the given message to use.
     */
    public EntityNotFoundException(final String message) {
        super(message);
    }

}
